@@ -1,3 +1,3 @@
 from sflux.client import Client
-from sflux.utils import ROW, _or, _and
+from sflux.utils import ROW, or_, and_
 from sflux.measurement import Measurement
